#!/bin/bash
#clean_backgrounddb.sh
set -euo pipefail


# Check for required dependencies
command_check() {
  local required_command="$1"
  command -v "$required_command" >/dev/null 2>&1 || {
    echo "'$required_command' command not found. Make sure it's installed and in the PATH."
    exit 1
  }
}

# Validate input
validate_input() {
  if [ $# -ne 1 ]; then
    echo "Usage: $0 <namespace>"
    exit 1
  fi
}

# Validate the existence of the specified namespace
validate_namespace() {
    local namespace="$1"

    # Check if the provided namespace exists
    if ! kubectl get namespace "$namespace" &> /dev/null; then
        echo "Namespace '$namespace' not found."
        exit 1
    fi
}

# Function to stop deployments
stop_deployments() {
  local s_deployments=("$@")

  for deployment in "${s_deployments[@]}"; do
    kubectl scale deployment "$deployment" -n "$namespace" --replicas 0 > /dev/null 2>&1
  done
  for deployment in "${s_deployments[@]}"; do
    while ! [ -z "$(kubectl get deployment $deployment -n $namespace -o=jsonpath='{.status.readyReplicas}')" ]; do
      sleep 1
    done
  done
}

# Function to get pod name by deployment name
pod_by_deployment() {
  local deployment="$1"
  pod_name=$(kubectl get pods -l app="$deployment" -n "$namespace"  --output=jsonpath='{.items[0].metadata.name}')
}

# Function to execute comman in pod
execute_psql() {
  local pod_name="$1"
  local db="$2"
  local query="$3"

  kubectl exec "$pod_name" -n "$namespace" --  psql -d "$db" -c "$query"
}


main() {
  namespace="$1"
  validate_namespace "$namespace"
  # Stop frontend and deployments that use backgrounddb or globalsearchdb
  local deployments=("frontend" "background-service" "webapi" "globalsearch-service")
  stop_deployments "${deployments[@]}"
  pod_by_deployment "postgres"
  execute_psql "$pod_name" "backgrounddb" "DROP TABLE IF EXISTS public.\"SearchItems\", public.\"Resources\", public.\"Projects\", public.\"__EFMigrationsHistory\";" &> /dev/null
  echo "Done! Please proceed to the next update step"
}

# Validations before the script
validate_input "$@"
command_check "kubectl"
main "$@"